(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     29554,        711]
NotebookOptionsPosition[     28685,        681]
NotebookOutlinePosition[     29037,        696]
CellTagsIndexPosition[     28994,        693]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Codes for preparing to plot the figures", "Text",
 CellChangeTimes->{{3.789797091402213*^9, 3.7897971031744423`*^9}, {
  3.8128763089684525`*^9, 3.812876325153076*^9}, {3.8128872806721416`*^9, 
  3.8128872853603244`*^9}, {3.8161513208983283`*^9, 3.8161513462122517`*^9}}],

Cell[CellGroupData[{

Cell["Functions", "Section",
 CellChangeTimes->{{3.787482251010126*^9, 3.787482254955355*^9}, {
  3.7880909454743395`*^9, 3.7880909640633664`*^9}, {3.788779526673837*^9, 
  3.788779528962552*^9}, {3.816151354016706*^9, 3.8161513553935566`*^9}}],

Cell["\<\
1. Find the position of the point/site of interest over the model grid:\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.816151548992342*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"findpos", "[", 
    RowBox[{"latin_", ",", "lonin_", ",", "latlon_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dd", ",", "gp1", ",", "gp2"}], "}"}], ",", 
     RowBox[{
      RowBox[{"dd", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"latin", "-", 
            RowBox[{"latlon", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}]}], ")"}], 
          "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"lonin", "-", 
            RowBox[{"latlon", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}]}], ")"}], 
          "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gp1", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Position", "[", 
         RowBox[{"dd", ",", 
          RowBox[{"Min", "[", "dd", "]"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "gp1", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"latlon", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"gp1", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"gp1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"N", "[", "latin", "]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"N", "[", "lonin", "]"}], "}"}]}], "]"}], ";", "gp1"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.431929480319173*^9, 3.431929623882592*^9}, {
  3.4385919407978373`*^9, 3.4385919487195096`*^9}}],

Cell["2. Calculate the direction", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.816151573042681*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ObtainDir", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ",", 
        RowBox[{"270", "-", 
         RowBox[{
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "*", 
          RowBox[{"180", "/", "Pi"}]}]}], ",", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], ",", 
        RowBox[{"90", "-", 
         RowBox[{
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "*", 
          RowBox[{"180", "/", "Pi"}]}]}], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ">", "0"}]}], ")"}], ",", "180", 
        ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "<", "0"}]}], ")"}], ",", "0"}], 
       "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"u", ",", "v"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4322803296540685`*^9, 3.4322803807946935`*^9}}],

Cell["\<\
3. Get the time series from the given position from the WRF output files, \
with input of the position, the WRF-file, wished data length and wished \
vertical level number\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.8161516548656297`*^9, 3.816151693175099*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getwrfts", "[", 
    RowBox[{"pos_", ",", "fil_", ",", "dLen_", ",", "verL_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "id", ",", "u", ",", "v", ",", "Qke", ",", "ws", ",", "dir", ",", "T"}],
       "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id", "=", 
       RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"u", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"v", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"T", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Qke", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ws", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"u", "^", "2"}], "+", 
         RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"dir", "=", 
       RowBox[{"ObtainDir", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ";", 
      RowBox[{"{", 
       RowBox[{"ws", ",", "dir", ",", "T", ",", "Qke"}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.7886014426837015`*^9, 
   3.7886015328228106`*^9}, {3.788601865896428*^9, 3.7886018688855944`*^9}, {
   3.7886742652759285`*^9, 3.788674269599454*^9}, {3.789190998737625*^9, 
   3.78919101026676*^9}, 3.8161516169609995`*^9}],

Cell["\<\
4. Get 2D data (x-y) for one or more z-levels and one or more time stamps \
from the WRF output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.816151772730195*^9}, {3.816151807435397*^9, 
  3.8161518267697444`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfAREA1", "[", 
     RowBox[{"fil_", ",", "startz_", ",", "startt_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "id", ",", "u", ",", "v", ",", "zidx", ",", "ws", ",", "dir", ",", "T",
         ",", "sst", ",", "T2", ",", "qke"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"T", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"sst", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<SST\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "90", ",", "95"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"T2", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T2\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "90", ",", "95"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"dir", "=", 
          RowBox[{"ObtainDir", "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], ";"}], "*)"}], 
       RowBox[{"{", 
        RowBox[{"ws", ",", "T", ",", "sst", ",", "T2", ",", "qke"}], 
        "}"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.7898056049910245`*^9, 
   3.7898056490401936`*^9}, {3.790502325714153*^9, 3.790502354001898*^9}}],

Cell["\<\
5. Get a row of data for one or more z-levels and one time stamp from the WRF \
output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.8161518300820913`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfrow", "[", 
     RowBox[{"pos_", ",", "fil_", ",", "startz_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"id", ",", "u", ",", "v", ",", "ws", ",", "qke", ",", "lat"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"lat", "=", 
        RowBox[{"latd03", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"pos", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ";;", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "+", "29"}]}], ",", 
           RowBox[{"pos", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ws", ",", "qke", ",", "lat"}], "}"}]}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.788692497122455*^9, 3.788692498656822*^9}, {
   3.7886925376409807`*^9, 3.7886925746154704`*^9}, {3.788692650780055*^9, 
   3.788692656906662*^9}, {3.7886927181696396`*^9, 3.7886927335383844`*^9}, {
   3.7886929139747543`*^9, 3.788692919884385*^9}, 3.7886930616160383`*^9, {
   3.788693139257899*^9, 3.7886931444536104`*^9}, {3.7886946726054535`*^9, 
   3.7886946970836563`*^9}, {3.7898159073342123`*^9, 
   3.7898160383490295`*^9}, {3.789816135301789*^9, 3.789816136288871*^9}, {
   3.789885704498333*^9, 3.789885710923794*^9}}],

Cell["\<\
6. Get a transect of data for one or more z-levels and one time stamp from \
the WRF output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.816151888717077*^9}, {3.816151931023254*^9, 
  3.816151948633963*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{"pos_", ",", "fil_", ",", "startz_", ",", "nLa_", ",", "nT_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"id", ",", "u", ",", "v", ",", "ws", ",", "qke"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", 
       RowBox[{"{", 
        RowBox[{"ws", ",", "qke"}], "}"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.788692497122455*^9, 3.788692498656822*^9}, {
   3.7886925376409807`*^9, 3.7886925746154704`*^9}, {3.788692650780055*^9, 
   3.788692656906662*^9}, {3.7886927181696396`*^9, 3.7886927335383844`*^9}, {
   3.7886929139747543`*^9, 3.788692919884385*^9}, 3.7886930616160383`*^9, {
   3.788693139257899*^9, 3.7886931444536104`*^9}, {3.7886946726054535`*^9, 
   3.7886946970836563`*^9}, {3.788698072256164*^9, 3.7886980757957983`*^9}, {
   3.788698117320114*^9, 3.788698130106768*^9}, {3.790423995331352*^9, 
   3.7904240173696747`*^9}, {3.7904245500353355`*^9, 3.790424568664999*^9}, {
   3.7904902252951813`*^9, 3.790490250107786*^9}}],

Cell["7. Calculating TKE from flight data over 2 km: an example", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.816151888717077*^9}, {3.816151931023254*^9, 
  3.816151948633963*^9}, {3.8163145603207717`*^9, 3.8163145758207293`*^9}, {
  3.816314671075116*^9, 3.8163146759261494`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", 
   RowBox[{"Drop", "[", 
    RowBox[{"flightleg0", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DX", "=", "3125"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"about", " ", "2", "km"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TKE1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"xx", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"XX", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"i", "+", "DX"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"u1", "=", 
       RowBox[{
        RowBox[{"xx", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "5"}], "]"}], "]"}], "-", 
        RowBox[{"Mean", "[", 
         RowBox[{"xx", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "5"}], "]"}], "]"}], "]"}]}]}], ";", 
      RowBox[{"v1", "=", 
       RowBox[{
        RowBox[{"xx", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "6"}], "]"}], "]"}], "-", 
        RowBox[{"Mean", "[", 
         RowBox[{"xx", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "6"}], "]"}], "]"}], "]"}]}]}], ";", 
      RowBox[{"w1", "=", 
       RowBox[{
        RowBox[{"xx", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "7"}], "]"}], "]"}], "-", 
        RowBox[{"Mean", "[", 
         RowBox[{"xx", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "7"}], "]"}], "]"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"tke1", "=", 
       RowBox[{"0.5", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u1", "^", "2"}], "+", 
          RowBox[{"v1", "^", "2"}], "+", 
          RowBox[{"w1", "^", "2"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Mean", "[", 
         RowBox[{"xx", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
        RowBox[{"Mean", "[", "tke1", "]"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{
        RowBox[{"Length", "[", "XX", "]"}], "-", "DX"}], ",", "1000"}], 
      "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7891071577404823`*^9, 3.7891072872778044`*^9}, {
  3.789107322621956*^9, 3.78910746951443*^9}, {3.789107515408825*^9, 
  3.7891075163623705`*^9}, {3.789107590316324*^9, 3.789107594916083*^9}, {
  3.7891079722885785`*^9, 3.7891079755547113`*^9}, {3.7891080157821803`*^9, 
  3.7891080210279927`*^9}, {3.805708442359398*^9, 3.805708445282524*^9}, {
  3.805708655477777*^9, 3.8057086571903625`*^9}}]
}, Open  ]]
},
WindowSize->{1263, 621},
WindowMargins->{{Automatic, -485}, {Automatic, -1023}},
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (September 9, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 277, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[860, 27, 244, 3, 70, "Section"],
Cell[1107, 32, 163, 3, 30, "Text"],
Cell[1273, 37, 1830, 51, 132, "Input"],
Cell[3106, 90, 110, 1, 30, "Text"],
Cell[3219, 93, 1887, 55, 72, "Input"],
Cell[5109, 150, 316, 6, 30, "Text"],
Cell[5428, 158, 4801, 105, 192, "Input"],
Cell[10232, 265, 293, 6, 30, "Text"],
Cell[10528, 273, 4820, 103, 232, "Input"],
Cell[15351, 378, 235, 5, 30, "Text"],
Cell[15589, 385, 5061, 106, 212, "Input"],
Cell[20653, 493, 287, 6, 30, "Text"],
Cell[20943, 501, 4753, 96, 172, "Input"],
Cell[25699, 599, 341, 4, 30, "Text"],
Cell[26043, 605, 2626, 73, 172, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
